@@ -232,6 +232,7 @@ t.test('omit peer deps', t => {
       }
 
       const lock = require(tree.path + '/package-lock.json')
+      // eslint-disable-next-line promise/always-return
       for (const [loc, meta] of Object.entries(lock.packages)) {
         if (meta.peer) {
           t.throws(() => fs.statSync(resolve(path, loc)), 'peer not reified')
@@ -240,6 +241,7 @@ t.test('omit peer deps', t => {
         }
       }
     })
+  // eslint-disable-next-line promise/always-return
     .then(() => {
       process.removeListener('time', onTime)
       process.removeListener('timeEnd', onTimeEnd)
@@ -335,15 +337,15 @@ t.test('omit optional dep', t => {
   const ignoreScripts = true
 
   const arb = newArb({ path, ignoreScripts })
-  return arb.reify({ omit: ['optional'] })
-    .then(tree => {
-      t.equal(tree.children.get('fsevents'), undefined, 'no fsevents in tree')
-      t.throws(() => fs.statSync(path + '/node_modules/fsevents'), 'no fsevents unpacked')
-      t.match(require(path + '/package-lock.json').dependencies.fsevents, {
-        dev: true,
-        optional: true,
-      }, 'fsevents present in lockfile')
-    })
+  // eslint-disable-next-line promise/always-return
+  return arb.reify({ omit: ['optional'] }).then(tree => {
+    t.equal(tree.children.get('fsevents'), undefined, 'no fsevents in tree')
+    t.throws(() => fs.statSync(path + '/node_modules/fsevents'), 'no fsevents unpacked')
+    t.match(require(path + '/package-lock.json').dependencies.fsevents, {
+      dev: true,
+      optional: true,
+    }, 'fsevents present in lockfile')
+  })
     .then(() => t.ok(arb.diff, 'has a diff tree'))
 })
 
@@ -737,6 +739,7 @@ t.test('rollbacks', { buffered: false }, t => {
     return t.rejects(a.reify({
       update: ['@isaacs/testing-bundledeps-parent'],
     }).then(tree => 'it worked'), new Error('poop'))
+    // eslint-disable-next-line promise/always-return
       .then(() => {
         const warnings = check()
         t.equal(warnings.length, 2)
@@ -858,6 +861,7 @@ t.test('rollbacks', { buffered: false }, t => {
     return t.resolveMatchSnapshot(a.reify({
       update: ['@isaacs/testing-bundledeps-parent'],
       save: false,
+      // eslint-disable-next-line promise/always-return
     }).then(tree => printTree(tree))).then(() => {
       const warnings = check()
       t.equal(warnings.length, 2)
@@ -1019,6 +1023,7 @@ t.test('saving the ideal tree', t => {
       // NB: these are all going to be marked as extraneous, because we're
       // skipping the actual buildIdealTree step that flags them properly
       return a[kSaveIdealTree]({})
+      // eslint-disable-next-line promise/always-return
     }).then(saved => {
       t.ok(saved, 'true, because it was saved')
       t.matchSnapshot(require(path + '/package-lock.json'), 'lock after save')
@@ -1159,12 +1164,10 @@ t.test('workspaces', t => {
   t.test('reify simple-workspaces', t =>
     t.resolveMatchSnapshot(printReified(fixture(t, 'workspaces-simple')), 'should reify simple workspaces'))
 
-  t.test('reify workspaces lockfile', t => {
+  t.test('reify workspaces lockfile', async t => {
     const path = fixture(t, 'workspaces-simple')
-    reify(path).then(() => {
-      t.matchSnapshot(require(path + '/package-lock.json'), 'should lock workspaces config')
-      t.end()
-    })
+    await reify(path)
+    t.matchSnapshot(require(path + '/package-lock.json'), 'should lock workspaces config')
   })
 
   t.test('reify workspaces bin files', t => {
@@ -1195,20 +1198,16 @@ t.test('workspaces', t => {
       'should not clean up entire nm folder for no reason'
     ))
 
-  t.test('add new workspaces dep', t => {
+  t.test('add new workspaces dep', async t => {
     const path = fixture(t, 'workspaces-add-new-dep')
-    reify(path).then(() => {
-      t.matchSnapshot(require(path + '/package-lock.json'), 'should update package-lock with new added dep')
-      t.end()
-    })
+    await reify(path)
+    t.matchSnapshot(require(path + '/package-lock.json'), 'should update package-lock with new added dep')
   })
 
-  t.test('root as-a-workspace', t => {
+  t.test('root as-a-workspace', async t => {
     const path = fixture(t, 'workspaces-root-linked')
-    reify(path).then(() => {
-      t.matchSnapshot(require(path + '/package-lock.json'), 'should produce expected package-lock file')
-      t.end()
-    })
+    await reify(path)
+    t.matchSnapshot(require(path + '/package-lock.json'), 'should produce expected package-lock file')
   })
 
   t.end()
